==> chromium-93.0.4549.3.tar.xz: chromium-93.0.4549.3/chrome/browser/resources/settings/chromeos/os_settings.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import '../prefs/prefs.js';
import './ambient_mode_page/ambient_mode_page.js';
import './bluetooth_page/bluetooth_device_list_item.js';
import './bluetooth_page/bluetooth_page.js';
import './bluetooth_page/bluetooth_subpage.js';
import './device_page/device_page.m.js';
import './device_page/display.m.js';
import './device_page/display_layout.m.js';
import './device_page/display_overscan_dialog.m.js';
import './device_page/keyboard.m.js';
import './device_page/night_light_slider.m.js';
import './device_page/pointers.m.js';
import './device_page/power.m.js';
import './device_page/storage.m.js';
import './device_page/storage_external.m.js';
import './device_page/storage_external_entry.m.js';
import './device_page/stylus.m.js';
import './google_assistant_page/google_assistant_page.js';
import './internet_page/cellular_setup_dialog.m.js';
import './internet_page/esim_remove_profile_dialog.m.js';
import './internet_page/internet_config.m.js';
import './internet_page/internet_detail_page.m.js';
import './internet_page/internet_known_networks_page.m.js';
import './internet_page/internet_page.m.js';
import './internet_page/internet_subpage.m.js';
import './internet_page/network_always_on_vpn.m.js';
import './internet_page/network_proxy_section.m.js';
import './internet_page/network_summary.m.js';
import './internet_page/network_summary_item.m.js';
import './internet_page/tether_connection_dialog.m.js';
import './kerberos_page/kerberos_accounts.m.js';
import './kerberos_page/kerberos_page.m.js';
import './localized_link/localized_link.js';
import './multidevice_page/multidevice_page.m.js';
import './nearby_share_page/nearby_share_receive_dialog.m.js';
import './nearby_share_page/nearby_share_subpage.m.js';
import './personalization_page/change_picture.m.js';
import './personalization_page/dark_mode_subpage.m.js';
import './personalization_page/personalization_page.m.js';
import './os_about_page/channel_switcher_dialog.m.js';
import './os_about_page/detailed_build_info.m.js';
import './os_about_page/os_about_page.m.js';
import './os_about_page/update_warning_dialog.m.js';
import './os_apps_page/android_apps_subpage.m.js';
import './os_apps_page/app_management_page/app_item.m.js';
import './os_apps_page/app_management_page/app_detail_view.m.js';
import './os_apps_page/app_management_page/app_management_page.m.js';
import './os_apps_page/app_management_page/arc_detail_view.m.js';
import './os_apps_page/app_management_page/chrome_app_detail_view.m.js';
import './os_apps_page/app_management_page/dom_switch.m.js';
import './os_apps_page/app_management_page/icons.m.js';
import './os_apps_page/app_management_page/main_view.m.js';
import './os_apps_page/app_management_page/permission_item.m.js';
import './os_apps_page/app_management_page/pin_to_shelf_item.m.js';
import './os_apps_page/app_management_page/plugin_vm_page/plugin_vm_detail_view.m.js';
import './os_apps_page/app_management_page/pwa_detail_view.m.js';
import './os_apps_page/app_management_page/shared_style.m.js';
import './os_apps_page/app_management_page/shared_vars.m.js';
import './os_apps_page/app_management_page/toggle_row.m.js';
import './os_apps_page/app_management_page/uninstall_button.m.js';
import './os_apps_page/os_apps_page.m.js';
import './os_icons.m.js';
import './os_people_page/account_manager.m.js';
import './os_people_page/os_people_page.m.js';
import './os_people_page/os_sync_controls.m.js';
import './os_search_page/os_search_page.m.js';
import './os_settings_main/os_settings_main.m.js';
import './os_settings_page/os_settings_page.m.js';
import './os_settings_page/settings_idle_load.m.js';
import './os_settings_menu/os_settings_menu.m.js';
import './os_settings_ui/os_settings_ui.m.js';
import './os_settings_icons_css.m.js';
import './os_settings_search_box/os_search_result_row.m.js';
import './os_settings_search_box/os_settings_search_box.m.js';
import './os_toolbar/os_toolbar.m.js';
import './parental_controls_page/parental_controls_page.m.js';

export {AboutPageBrowserProxyImpl, BrowserChannel, UpdateStatus} from '../about_page/about_page_browser_proxy.js';
export {LifetimeBrowserProxy, LifetimeBrowserProxyImpl} from '../lifetime_browser_proxy.js';
export {pageVisibility} from '../page_visibility.js';
export {AccountManagerBrowserProxy, AccountManagerBrowserProxyImpl} from '../people_page/account_manager_browser_proxy.js';
export {ProfileInfoBrowserProxy, ProfileInfoBrowserProxyImpl} from '../people_page/profile_info_browser_proxy.js';
export {PageStatus, StatusAction, StoredAccount, SyncBrowserProxy, SyncBrowserProxyImpl, SyncStatus} from '../people_page/sync_browser_proxy.js';
export {CrSettingsPrefs} from '../prefs/prefs_types.js';
export {PrivacyPageBrowserProxy, PrivacyPageBrowserProxyImpl, ResolverOption, SecureDnsMode, SecureDnsSetting, SecureDnsUiManagementMode} from '../privacy_page/privacy_page_browser_proxy.js';
export {Route, Router} from '../router.js';
export {SearchEngine, SearchEnginesBrowserProxy, SearchEnginesBrowserProxyImpl, SearchEnginesInfo} from '../search_engines_page/search_engines_browser_proxy.js';
export {getSearchManager, SearchRequest, SearchResult, setSearchManagerForTesting} from '../search_settings.js';
export {getContactManager, observeContactManager, setContactManagerForTesting} from '../shared/nearby_contact_manager.m.js';
export {getNearbyShareSettings, observeNearbyShareSettings, setNearbyShareSettingsForTesting} from '../shared/nearby_share_settings.m.js';
export {NearbySettings, NearbyShareSettingsBehavior} from '../shared/nearby_share_settings_behavior.m.js';
export {AmbientModeBrowserProxyImpl} from './ambient_mode_page/ambient_mode_browser_proxy.js';
export {AmbientModeTemperatureUnit, AmbientModeTopicSource} from './ambient_mode_page/constants.js';
export {bluetoothApis} from './bluetooth_page/bluetooth_page.js';
export {BluetoothPageBrowserProxyImpl} from './bluetooth_page/bluetooth_page_browser_proxy.js';
export {DevicePageBrowserProxy, DevicePageBrowserProxyImpl, IdleBehavior, LidClosedBehavior, NoteAppLockScreenSupport, setDisplayApiForTesting, StorageSpaceState} from './device_page/device_page_browser_proxy.m.js';
export {GoogleAssistantBrowserProxyImpl} from './google_assistant_page/google_assistant_browser_proxy.js';
export {ConsentStatus, DspHotwordState} from './google_assistant_page/google_assistant_page.js';
export {InternetPageBrowserProxy, InternetPageBrowserProxyImpl} from './internet_page/internet_page_browser_proxy.m.js';
export {KerberosAccountsBrowserProxyImpl, KerberosConfigErrorCode, KerberosErrorType} from './kerberos_page/kerberos_accounts_browser_proxy.m.js';
export {recordClick, recordNavigation, recordPageBlur, recordPageFocus, recordSearch, recordSettingChange, setUserActionRecorderForTesting} from './metrics_recorder.m.js';
export {MultiDeviceBrowserProxy, MultiDeviceBrowserProxyImpl} from './multidevice_page/multidevice_browser_proxy.m.js';
export {MultiDeviceFeature, MultiDeviceFeatureState, MultiDevicePageContentData, MultiDeviceSettingsMode, PhoneHubNotificationAccessStatus, SmartLockSignInEnabledState} from './multidevice_page/multidevice_constants.m.js';
export {NotificationAccessSetupOperationStatus} from './multidevice_page/multidevice_notification_access_setup_dialog.m.js';
export {Account, NearbyAccountManagerBrowserProxy, NearbyAccountManagerBrowserProxyImpl} from './nearby_share_page/nearby_account_manager_browser_proxy.m.js';
export {getReceiveManager, observeReceiveManager, setReceiveManagerForTesting} from './nearby_share_page/nearby_share_receive_manager.m.js';
export {dataUsageStringToEnum, NearbyShareDataUsage} from './nearby_share_page/types.m.js';
export {ManageA11yPageBrowserProxy, ManageA11yPageBrowserProxyImpl} from './os_a11y_page/manage_a11y_page_browser_proxy.m.js';
export {OsA11yPageBrowserProxy, OsA11yPageBrowserProxyImpl} from './os_a11y_page/os_a11y_page_browser_proxy.m.js';
export {SwitchAccessSubpageBrowserProxy, SwitchAccessSubpageBrowserProxyImpl} from './os_a11y_page/switch_access_subpage_browser_proxy.m.js';
export {TtsSubpageBrowserProxy, TtsSubpageBrowserProxyImpl} from './os_a11y_page/tts_subpage_browser_proxy.m.js';
export {DeviceNameBrowserProxy, DeviceNameBrowserProxyImpl} from './os_about_page/device_name_browser_proxy.m.js';
export {AndroidAppsBrowserProxyImpl} from './os_apps_page/android_apps_browser_proxy.m.js';
export {addApp, changeApp, removeApp, updateSelectedAppId} from './os_apps_page/app_management_page/actions.m.js';
export {BrowserProxy} from './os_apps_page/app_management_page/browser_proxy.m.js';
export {ArcPermissionType, Bool, PageType, PermissionValueType, PluginVmPermissionType, PwaPermissionType, TriState} from './os_apps_page/app_management_page/constants.m.js';
export {FakePageHandler} from './os_apps_page/app_management_page/fake_page_handler.m.js';
export {PluginVmBrowserProxyImpl} from './os_apps_page/app_management_page/plugin_vm_page/plugin_vm_browser_proxy.m.js';
export {AppState, reduceAction} from './os_apps_page/app_management_page/reducers.m.js';
export {AppManagementStore} from './os_apps_page/app_management_page/store.m.js';
export {convertOptionalBoolToBool, createEmptyState, createInitialState, createPermission, getPermissionValueBool} from './os_apps_page/app_management_page/util.m.js';
export {FingerprintBrowserProxyImpl, FingerprintResultType} from './os_people_page/fingerprint_browser_proxy.m.js';
export {OsSyncBrowserProxyImpl} from './os_people_page/os_sync_browser_proxy.m.js';
export {FingerprintLocation, FingerprintSetupStep} from './os_people_page/setup_fingerprint_dialog.m.js';
export {DataAccessPolicyState, PeripheralDataAccessBrowserProxy, PeripheralDataAccessBrowserProxyImpl} from './os_privacy_page/peripheral_data_access_browser_proxy.js';
export {OsResetBrowserProxyImpl} from './os_reset_page/os_reset_browser_proxy.js';
export {routes} from './os_route.m.js';
export {ParentalControlsBrowserProxy, ParentalControlsBrowserProxyImpl} from './parental_controls_page/parental_controls_browser_proxy.m.js';
export {ChangePictureBrowserProxy, ChangePictureBrowserProxyImpl} from './personalization_page/change_picture_browser_proxy.js';
export {WallpaperBrowserProxyImpl} from './personalization_page/wallpaper_browser_proxy.js';
export {getSearchHandler, setSearchHandlerForTesting} from './search_handler.m.js';

==> chromium-93.0.4567.0.tar.xz: chromium-93.0.4567.0/chrome/browser/resources/settings/chromeos/os_settings.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import '../prefs/prefs.js';
import './ambient_mode_page/ambient_mode_page.js';
import './bluetooth_page/bluetooth_device_list_item.js';
import './bluetooth_page/bluetooth_page.js';
import './bluetooth_page/bluetooth_subpage.js';
import './device_page/device_page.m.js';
import './device_page/display.m.js';
import './device_page/display_layout.m.js';
import './device_page/display_overscan_dialog.m.js';
import './device_page/keyboard.m.js';
import './device_page/night_light_slider.m.js';
import './device_page/pointers.m.js';
import './device_page/power.m.js';
import './device_page/storage.m.js';
import './device_page/storage_external.m.js';
import './device_page/storage_external_entry.m.js';
import './device_page/stylus.m.js';
import './google_assistant_page/google_assistant_page.js';
import './internet_page/cellular_roaming_toggle_button.m.js';
import './internet_page/cellular_setup_dialog.m.js';
import './internet_page/esim_remove_profile_dialog.m.js';
import './internet_page/internet_config.m.js';
import './internet_page/internet_detail_page.m.js';
import './internet_page/internet_known_networks_page.m.js';
import './internet_page/internet_page.m.js';
import './internet_page/internet_subpage.m.js';
import './internet_page/network_always_on_vpn.m.js';
import './internet_page/network_proxy_section.m.js';
import './internet_page/network_summary.m.js';
import './internet_page/network_summary_item.m.js';
import './internet_page/tether_connection_dialog.m.js';
import './kerberos_page/kerberos_accounts.m.js';
import './kerberos_page/kerberos_page.m.js';
import './localized_link/localized_link.js';
import './multidevice_page/multidevice_page.m.js';
import './nearby_share_page/nearby_share_receive_dialog.m.js';
import './nearby_share_page/nearby_share_subpage.m.js';
import './personalization_page/change_picture.m.js';
import './personalization_page/dark_mode_subpage.m.js';
import './personalization_page/personalization_page.m.js';
import './os_about_page/channel_switcher_dialog.m.js';
import './os_about_page/detailed_build_info.m.js';
import './os_about_page/os_about_page.m.js';
import './os_about_page/update_warning_dialog.m.js';
import './os_apps_page/android_apps_subpage.m.js';
import './os_apps_page/app_notifications_page/app_notifications_subpage.js';
import './os_apps_page/app_management_page/app_item.m.js';
import './os_apps_page/app_management_page/app_detail_view.m.js';
import './os_apps_page/app_management_page/app_management_page.m.js';
import './os_apps_page/app_management_page/arc_detail_view.m.js';
import './os_apps_page/app_management_page/chrome_app_detail_view.m.js';
import './os_apps_page/app_management_page/dom_switch.m.js';
import './os_apps_page/app_management_page/icons.m.js';
import './os_apps_page/app_management_page/main_view.m.js';
import './os_apps_page/app_management_page/permission_item.m.js';
import './os_apps_page/app_management_page/pin_to_shelf_item.m.js';
import './os_apps_page/app_management_page/plugin_vm_page/plugin_vm_detail_view.m.js';
import './os_apps_page/app_management_page/pwa_detail_view.m.js';
import './os_apps_page/app_management_page/shared_style.m.js';
import './os_apps_page/app_management_page/shared_vars.m.js';
import './os_apps_page/app_management_page/supported_links_item.m.js';
import './os_apps_page/app_management_page/toggle_row.m.js';
import './os_apps_page/app_management_page/uninstall_button.m.js';
import './os_apps_page/os_apps_page.m.js';
import './os_icons.m.js';
import './os_people_page/account_manager.m.js';
import './os_people_page/os_people_page.m.js';
import './os_people_page/os_sync_controls.m.js';
import './os_search_page/os_search_page.m.js';
import './os_settings_main/os_settings_main.m.js';
import './os_settings_page/os_settings_page.m.js';
import './os_settings_page/settings_idle_load.m.js';
import './os_settings_menu/os_settings_menu.m.js';
import './os_settings_ui/os_settings_ui.m.js';
import './os_settings_icons_css.m.js';
import './os_settings_search_box/os_search_result_row.m.js';
import './os_settings_search_box/os_settings_search_box.m.js';
import './os_toolbar/os_toolbar.m.js';
import './parental_controls_page/parental_controls_page.m.js';

export {AboutPageBrowserProxyImpl, BrowserChannel, UpdateStatus} from '../about_page/about_page_browser_proxy.js';
export {LifetimeBrowserProxy, LifetimeBrowserProxyImpl} from '../lifetime_browser_proxy.js';
export {pageVisibility} from '../page_visibility.js';
export {AccountManagerBrowserProxy, AccountManagerBrowserProxyImpl} from '../people_page/account_manager_browser_proxy.js';
export {ProfileInfoBrowserProxy, ProfileInfoBrowserProxyImpl} from '../people_page/profile_info_browser_proxy.js';
export {PageStatus, StatusAction, StoredAccount, SyncBrowserProxy, SyncBrowserProxyImpl, SyncStatus} from '../people_page/sync_browser_proxy.js';
export {CrSettingsPrefs} from '../prefs/prefs_types.js';
export {PrivacyPageBrowserProxy, PrivacyPageBrowserProxyImpl, ResolverOption, SecureDnsMode, SecureDnsSetting, SecureDnsUiManagementMode} from '../privacy_page/privacy_page_browser_proxy.js';
export {Route, Router} from '../router.js';
export {SearchEngine, SearchEnginesBrowserProxy, SearchEnginesBrowserProxyImpl, SearchEnginesInfo} from '../search_engines_page/search_engines_browser_proxy.js';
export {getSearchManager, SearchRequest, SearchResult, setSearchManagerForTesting} from '../search_settings.js';
export {getContactManager, observeContactManager, setContactManagerForTesting} from '../shared/nearby_contact_manager.m.js';
export {getNearbyShareSettings, observeNearbyShareSettings, setNearbyShareSettingsForTesting} from '../shared/nearby_share_settings.m.js';
export {NearbySettings, NearbyShareSettingsBehavior} from '../shared/nearby_share_settings_behavior.m.js';
export {AmbientModeBrowserProxyImpl} from './ambient_mode_page/ambient_mode_browser_proxy.js';
export {AmbientModeTemperatureUnit, AmbientModeTopicSource} from './ambient_mode_page/constants.js';
export {bluetoothApis} from './bluetooth_page/bluetooth_page.js';
export {BluetoothPageBrowserProxyImpl} from './bluetooth_page/bluetooth_page_browser_proxy.js';
export {DevicePageBrowserProxy, DevicePageBrowserProxyImpl, IdleBehavior, LidClosedBehavior, NoteAppLockScreenSupport, setDisplayApiForTesting, StorageSpaceState} from './device_page/device_page_browser_proxy.m.js';
export {GoogleAssistantBrowserProxyImpl} from './google_assistant_page/google_assistant_browser_proxy.js';
export {ConsentStatus, DspHotwordState} from './google_assistant_page/google_assistant_page.js';
export {InternetPageBrowserProxy, InternetPageBrowserProxyImpl} from './internet_page/internet_page_browser_proxy.m.js';
export {KerberosAccountsBrowserProxyImpl, KerberosConfigErrorCode, KerberosErrorType} from './kerberos_page/kerberos_accounts_browser_proxy.m.js';
export {recordClick, recordNavigation, recordPageBlur, recordPageFocus, recordSearch, recordSettingChange, setUserActionRecorderForTesting} from './metrics_recorder.m.js';
export {MultiDeviceBrowserProxy, MultiDeviceBrowserProxyImpl} from './multidevice_page/multidevice_browser_proxy.m.js';
export {MultiDeviceFeature, MultiDeviceFeatureState, MultiDevicePageContentData, MultiDeviceSettingsMode, PhoneHubNotificationAccessStatus, SmartLockSignInEnabledState} from './multidevice_page/multidevice_constants.m.js';
export {NotificationAccessSetupOperationStatus} from './multidevice_page/multidevice_notification_access_setup_dialog.m.js';
export {Account, NearbyAccountManagerBrowserProxy, NearbyAccountManagerBrowserProxyImpl} from './nearby_share_page/nearby_account_manager_browser_proxy.m.js';
export {getReceiveManager, observeReceiveManager, setReceiveManagerForTesting} from './nearby_share_page/nearby_share_receive_manager.m.js';
export {dataUsageStringToEnum, NearbyShareDataUsage} from './nearby_share_page/types.m.js';
export {ManageA11yPageBrowserProxy, ManageA11yPageBrowserProxyImpl} from './os_a11y_page/manage_a11y_page_browser_proxy.m.js';
export {OsA11yPageBrowserProxy, OsA11yPageBrowserProxyImpl} from './os_a11y_page/os_a11y_page_browser_proxy.m.js';
export {SwitchAccessSubpageBrowserProxy, SwitchAccessSubpageBrowserProxyImpl} from './os_a11y_page/switch_access_subpage_browser_proxy.m.js';
export {TtsSubpageBrowserProxy, TtsSubpageBrowserProxyImpl} from './os_a11y_page/tts_subpage_browser_proxy.m.js';
export {DeviceNameBrowserProxy, DeviceNameBrowserProxyImpl} from './os_about_page/device_name_browser_proxy.m.js';
export {AndroidAppsBrowserProxyImpl} from './os_apps_page/android_apps_browser_proxy.m.js';
export {addApp, changeApp, removeApp, updateSelectedAppId} from './os_apps_page/app_management_page/actions.m.js';
export {BrowserProxy} from './os_apps_page/app_management_page/browser_proxy.m.js';
export {ArcPermissionType, Bool, PageType, PermissionValueType, PluginVmPermissionType, PwaPermissionType, TriState, WindowMode} from './os_apps_page/app_management_page/constants.m.js';
export {FakePageHandler} from './os_apps_page/app_management_page/fake_page_handler.m.js';
export {PluginVmBrowserProxyImpl} from './os_apps_page/app_management_page/plugin_vm_page/plugin_vm_browser_proxy.m.js';
export {AppState, reduceAction} from './os_apps_page/app_management_page/reducers.m.js';
export {AppManagementStore} from './os_apps_page/app_management_page/store.m.js';
export {convertOptionalBoolToBool, createEmptyState, createInitialState, createPermission, getPermissionValueBool} from './os_apps_page/app_management_page/util.m.js';
export {FingerprintBrowserProxyImpl, FingerprintResultType} from './os_people_page/fingerprint_browser_proxy.m.js';
export {OsSyncBrowserProxyImpl} from './os_people_page/os_sync_browser_proxy.m.js';
export {FingerprintLocation, FingerprintSetupStep} from './os_people_page/setup_fingerprint_dialog.m.js';
export {DataAccessPolicyState, PeripheralDataAccessBrowserProxy, PeripheralDataAccessBrowserProxyImpl} from './os_privacy_page/peripheral_data_access_browser_proxy.js';
export {OsResetBrowserProxyImpl} from './os_reset_page/os_reset_browser_proxy.js';
export {routes} from './os_route.m.js';
export {ParentalControlsBrowserProxy, ParentalControlsBrowserProxyImpl} from './parental_controls_page/parental_controls_browser_proxy.m.js';
export {ChangePictureBrowserProxy, ChangePictureBrowserProxyImpl} from './personalization_page/change_picture_browser_proxy.js';
export {WallpaperBrowserProxyImpl} from './personalization_page/wallpaper_browser_proxy.js';
export {getSearchHandler, setSearchHandlerForTesting} from './search_handler.m.js';
